@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use locale;
 
-our $VERSION = "0.93";
+our $VERSION = "0.95";
 
 =head1 NAME
 
@@ -195,7 +195,9 @@ use constant DEFAULT => {
 
   rxAnd       => qr/AND|ET|UND|E/,
   rxOr        => qr/OR|OU|ODER|O/,
-  rxNot       => qr/NOT|PAS|NICHT|NON/
+  rxNot       => qr/NOT|PAS|NICHT|NON/,
+
+  defField    => "",
 };
 
 =item new
@@ -254,6 +256,11 @@ Default value is C<qr/OR|OU|ODER|O/>.
 Regular expression for boolean connector NOT.
 Default value is C<qr/NOT|PAS|NICHT|NON/>.
 
+=item defField
+
+If no field is specified in the query, use I<defField>.
+The default is the empty string "".
+
 =back
 
 =cut
@@ -265,7 +272,7 @@ sub new {
   # create object with default values
   my $self = bless {}, $class;
   $self->{$_} = $args->{$_} || DEFAULT->{$_} 
-    foreach qw(rxTerm rxField rxOp rxOpNoField rxAnd rxOr rxNot);
+    foreach qw(rxTerm rxField rxOp rxOpNoField rxAnd rxOr rxNot defField);
   return $self;
 }
 
@@ -336,19 +343,27 @@ method L<err> can be called to get an explanatory message.
 
 
 
-sub parse { return (_parse(@_))[0]; } # just return 1st result from _parse
+sub parse {
+  my $self = shift;
+  my $s_orig = $_[0];
+  my ($parsedQuery, $restOfString) = $self->_parse(@_);
+  if ($restOfString) {
+    $self->{err} ||= "[$s_orig] : parsed into " . $self->unparse($parsedQuery)
+                   . ", but unable to parse [$restOfString]";
+    return undef;
+  }
+
+  return $parsedQuery;
+}
+
 
 sub _parse{ # returns ($parsedQuery, $restOfString)
-  my $self = shift;
-  my $s = shift;
-  my $implicitPlus = shift;
-  my $parentField = shift;	# only for recursive calls
-  my $parentOp = shift;		# only for recursive calls
+  my ($self, $s, $implicitPlus, $parentField, $parentOp) = @_; # last 2 args only for recursive calls
 
-  my $q = {};
+  my $q       = {};
   my $preBool = '';
-  my $err = undef;
-  my $s_orig = $s;
+  my $err     = undef;
+  my $s_orig  = $s;
 
   $s =~ s/^\s+//; # remove leading spaces
 
@@ -356,7 +371,7 @@ LOOP :
   while ($s) { # while query string is not empty
     for ($s) { # temporary alias to $_ for easier regex application
       my $sign = $implicitPlus ? "+" : "";
-      my $field = $parentField || "";
+      my $explicit_field;
       my $op = $parentOp || ":";
 
       last LOOP if m/^\)/; # return from recursive call if meeting a ')'
@@ -366,13 +381,21 @@ LOOP :
       elsif (s/^($self->{rxNot})\b\s*//) { $sign = '-'; }
 
       # try to parse field name and operator
-      if (s/^($self->{rxField})\s*($self->{rxOp})\s*// # field name and op
-	  or                                           # or
-	  s/^()($self->{rxOpNoField})\s*//) {          # no field, just op
-      	$err = "field '$1' inside '$parentField'", last LOOP if $parentField;
-	($field, $op) = ($1, $2); 
+      if (s/^"($self->{rxField})"\s*($self->{rxOp})\s*// # "field name" and op
+          or 
+          s/^'($self->{rxField})'\s*($self->{rxOp})\s*// # 'field name' and op
+          or 
+          s/^($self->{rxField})\s*($self->{rxOp})\s*//   # field name and op
+	  or
+	  s/^()($self->{rxOpNoField})\s*//) {            # no field, just op
+	($explicit_field, $op) = ($1, $2);
+      	$err = "field '$explicit_field' inside '$parentField'", last LOOP if $parentField;
       }
 
+      # target field, either explicit or implicit
+      my $field = $explicit_field || $parentField || $self->{defField};
+
+
       # parse a value (single term or quoted list or parens)
       my $subQ = undef;
 
@@ -382,7 +405,7 @@ LOOP :
 	$subQ = {field=>$field, op=>$op, value=>$val, quote=>$quote};
       }
       elsif (s/^\(\s*//) { # parse parentheses 
-	my ($r, $s2) = $self->_parse($s, $implicitPlus, $field, $op);
+	my ($r, $s2) = $self->_parse($s, $implicitPlus, $explicit_field, $op);
 	$err = $self->err, last LOOP if not $r; 
 	$s = $s2;
 	$s =~ s/^\)\s*// or $err = "no matching ) ", last LOOP;
@@ -411,7 +434,7 @@ LOOP :
       }
       else {
 	$err = "unexpected string in query : $_", last LOOP if $_;
-	$err = "missing value after $field $op", last LOOP if $field;
+	$err = "missing value after $field $op" , last LOOP if $field;
       }
     }
   }
